import requests


class MikeRacingF1:
    def __init__(self):
        self.base_url = "https://api.f1stats.io/v1.0/api/"
        self.token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9"

    def get_circuits(self, year):
        url = f"{self.base_url}circuits"
        params = {"token": self.token, "year": year}
        response = requests.get(url, params=params)
        return response.json()

    def get_constructor_results(self, year):
        url = f"{self.base_url}constructorresults"
        params = {"token": self.token, "year": year}
        response = requests.get(url, params=params)
        return response.json()

    def get_constructor_list(self):
        url = f"{self.base_url}constructors"
        params = {"token": self.token}
        response = requests.get(url, params=params)
        return response.json()

    def get_constructorstandings(self):
        url = f"{self.base_url}constructorstandings"
        params = {"token": self.token}
        response = requests.get(url, params=params)
        return response.json()

    def get_driversinfo(self,year):
        url = f"{self.base_url}driversinfo"
        params = {"token": self.token, "year": year}
        response = requests.get(url, params=params)
        return response.json()

    def get_driverstandings(self,year):
        url = f"{self.base_url}driverstandings"
        params = {"token": self.token, "year": year}
        response = requests.get(url, params=params)
        return response.json()

    def get_races(self,year):
        url = f"{self.base_url}races"
        params = {"token": self.token, "year": year}
        response = requests.get(url, params=params)
        return response.json()


    def get_results(self, year,round):
        url = f"{self.base_url}results"
        params = {"token": self.token, "year": year, "round": round}
        response = requests.get(url, params=params)
        return response.json()






from setuptools import setup, find_packages


with open("README.md", "r") as fh:
    long_description = fh.read()
setup(
    name='mikeracingf1',
    version='0.0.5',
    author='Michele Berardi',
    author_email='michymak@gmail.com',
    url='https://github.com/micheleberardi/mikeracingf1',
    packages=find_packages(),
    install_requires=['requests'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    description= 'A package for get Formula One Data',
    long_description=long_description,
    long_description_content_type="text/markdown",
)